summaryrefslogtreecommitdiffstats
path: root/ksquirrel/ksquirrelpart/sq_imagefilter.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/ksquirrelpart/sq_imagefilter.ui.h')
-rw-r--r--ksquirrel/ksquirrelpart/sq_imagefilter.ui.h78
1 files changed, 39 insertions, 39 deletions
diff --git a/ksquirrel/ksquirrelpart/sq_imagefilter.ui.h b/ksquirrel/ksquirrelpart/sq_imagefilter.ui.h
index d39f35f..c5ffc3d 100644
--- a/ksquirrel/ksquirrelpart/sq_imagefilter.ui.h
+++ b/ksquirrel/ksquirrelpart/sq_imagefilter.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/
@@ -41,7 +41,7 @@ void SQ_ImageFilter::init()
buttonGroupSwapRGB->setButton(SQ_Config::instance()->readNumEntry("filter_swapRGB", 0));
// blend
- QColor c;
+ TQColor c;
c.setNamedColor(SQ_Config::instance()->readEntry("filter_blend_color", "#00ff00"));
pushBlendColor->setColor(c);
blendOpacity->setValue(SQ_Config::instance()->readDoubleNumEntry("filter_blend_opacity", 0.5));
@@ -152,7 +152,7 @@ void SQ_ImageFilter::slotStartFiltering()
{
case F::fblend:
{
- QColor c = pushBlendColor->color();
+ TQColor c = pushBlendColor->color();
opt.rgb1 = fmt_filters::rgb(c.red(), c.green(), c.blue());
opt._float = blendOpacity->value();
}
@@ -165,14 +165,14 @@ void SQ_ImageFilter::slotStartFiltering()
case F::fequalize: break;
case F::ffade:
{
- QColor c = fadeColor->color();
+ TQColor c = fadeColor->color();
opt.rgb1 = fmt_filters::rgb(c.red(), c.green(), c.blue());
opt._float = (float)fadeValue->value();
}
break;
case F::fflatten:
{
- QColor c = flattenColor1->color();
+ TQColor c = flattenColor1->color();
opt.rgb1 = fmt_filters::rgb(c.red(), c.green(), c.blue());
c = flattenColor2->color();
opt.rgb2 = fmt_filters::rgb(c.red(), c.green(), c.blue());
@@ -229,14 +229,14 @@ void SQ_ImageFilter::slotShowPage()
}
}
-void SQ_ImageFilter::setPreviewImage(const QImage &im)
+void SQ_ImageFilter::setPreviewImage(const TQImage &im)
{
if(im.isNull()) return;
sample = im.copy();
sample_saved = sample.copy();
- QPixmap p;
+ TQPixmap p;
p.convertFromImage(sample_saved);
pixmap->setPixmap(p);
@@ -245,9 +245,9 @@ void SQ_ImageFilter::setPreviewImage(const QImage &im)
slotShowPage();
}
-void SQ_ImageFilter::assignNewImage(const QImage &im)
+void SQ_ImageFilter::assignNewImage(const TQImage &im)
{
- QPixmap p;
+ TQPixmap p;
p.convertFromImage(im);
pixmap1->setPixmap(p);
}
@@ -294,7 +294,7 @@ void SQ_ImageFilter::blend()
fmt_filters::image im(sample.bits(), sample.width(), sample.height());
- QColor c = pushBlendColor->color();
+ TQColor c = pushBlendColor->color();
fmt_filters::rgb rgb(c.red(), c.green(), c.blue());
@@ -312,7 +312,7 @@ void SQ_ImageFilter::fade()
fmt_filters::image im(sample.bits(), sample.width(), sample.height());
- QColor c = fadeColor->color();
+ TQColor c = fadeColor->color();
fmt_filters::fade(im, fmt_filters::rgb(c.red(), c.green(), c.blue()), fadeValue->value());
@@ -440,8 +440,8 @@ void SQ_ImageFilter::flatten()
fmt_filters::image im(sample.bits(), sample.width(), sample.height());
- QColor c1 = flattenColor1->color();
- QColor c2 = flattenColor2->color();
+ TQColor c1 = flattenColor1->color();
+ TQColor c2 = flattenColor2->color();
fmt_filters::flatten(im, fmt_filters::rgb(c1.red(), c1.green(), c1.blue()), fmt_filters::rgb(c2.red(), c2.green(), c2.blue()));
@@ -576,32 +576,32 @@ void SQ_ImageFilter::oil()
void SQ_ImageFilter::hackConnect()
{
- connect( blendOpacity, SIGNAL( valueChanged(double) ), this, SLOT( blend() ) );
- connect( pushBlendColor, SIGNAL( changed(const QColor&) ), this, SLOT( blend() ) );
- connect( blurRadius, SIGNAL( valueChanged(double) ), this, SLOT( blur() ) );
- connect( blurSigma, SIGNAL( valueChanged(double) ), this, SLOT( blur() ) );
- connect( desaturateValue, SIGNAL( valueChanged(double) ), this, SLOT( desaturate() ) );
- connect( edgeRadius, SIGNAL( valueChanged(int) ), this, SLOT( edge() ) );
- connect( embossRadius, SIGNAL( valueChanged(double) ), this, SLOT( emboss() ) );
- connect( embossSigma, SIGNAL( valueChanged(double) ), this, SLOT( emboss() ) );
- connect( fadeColor, SIGNAL( changed(const QColor&) ), this, SLOT( fade() ) );
- connect( fadeValue, SIGNAL( valueChanged(double) ), this, SLOT( fade() ) );
- connect( flattenColor1, SIGNAL( changed(const QColor&) ), this, SLOT( flatten() ) );
- connect( flattenColor2, SIGNAL( changed(const QColor&) ), this, SLOT( flatten() ) );
- connect( implodeFactor, SIGNAL( valueChanged(double) ), this, SLOT( implode() ) );
- connect( buttonGroupNoise, SIGNAL( clicked(int) ), this, SLOT( noise() ) );
- connect( oilRadius, SIGNAL( valueChanged(int) ), this, SLOT( oil() ) );
- connect( shadeAzim, SIGNAL( valueChanged(double) ), this, SLOT( shade() ) );
- connect( shadeColor, SIGNAL( toggled(bool) ), this, SLOT( shade() ) );
- connect( shadeElev, SIGNAL( valueChanged(double) ), this, SLOT( shade() ) );
- connect( sharpenRadius, SIGNAL( valueChanged(double) ), this, SLOT( sharpen() ) );
- connect( sharpenSigma, SIGNAL( valueChanged(double) ), this, SLOT( sharpen() ) );
- connect( solarizeValue, SIGNAL( valueChanged(double) ), this, SLOT( solarize() ) );
- connect( spreadValue, SIGNAL( valueChanged(int) ), this, SLOT( spread() ) );
- connect( buttonGroupSwapRGB, SIGNAL( clicked(int) ), this, SLOT( swapRGB() ) );
- connect( swirlAngle, SIGNAL( valueChanged(double) ), this, SLOT( swirl() ) );
- connect( thresholdValue, SIGNAL( valueChanged(int) ), this, SLOT( threshold() ) );
- connect( thresholdRE, SIGNAL( valueChanged(int) ), this, SLOT( redeye() ) );
+ connect( blendOpacity, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( blend() ) );
+ connect( pushBlendColor, TQT_SIGNAL( changed(const TQColor&) ), this, TQT_SLOT( blend() ) );
+ connect( blurRadius, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( blur() ) );
+ connect( blurSigma, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( blur() ) );
+ connect( desaturateValue, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( desaturate() ) );
+ connect( edgeRadius, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( edge() ) );
+ connect( embossRadius, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( emboss() ) );
+ connect( embossSigma, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( emboss() ) );
+ connect( fadeColor, TQT_SIGNAL( changed(const TQColor&) ), this, TQT_SLOT( fade() ) );
+ connect( fadeValue, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( fade() ) );
+ connect( flattenColor1, TQT_SIGNAL( changed(const TQColor&) ), this, TQT_SLOT( flatten() ) );
+ connect( flattenColor2, TQT_SIGNAL( changed(const TQColor&) ), this, TQT_SLOT( flatten() ) );
+ connect( implodeFactor, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( implode() ) );
+ connect( buttonGroupNoise, TQT_SIGNAL( clicked(int) ), this, TQT_SLOT( noise() ) );
+ connect( oilRadius, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( oil() ) );
+ connect( shadeAzim, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( shade() ) );
+ connect( shadeColor, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( shade() ) );
+ connect( shadeElev, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( shade() ) );
+ connect( sharpenRadius, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( sharpen() ) );
+ connect( sharpenSigma, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( sharpen() ) );
+ connect( solarizeValue, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( solarize() ) );
+ connect( spreadValue, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( spread() ) );
+ connect( buttonGroupSwapRGB, TQT_SIGNAL( clicked(int) ), this, TQT_SLOT( swapRGB() ) );
+ connect( swirlAngle, TQT_SIGNAL( valueChanged(double) ), this, TQT_SLOT( swirl() ) );
+ connect( thresholdValue, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( threshold() ) );
+ connect( thresholdRE, TQT_SIGNAL( valueChanged(int) ), this, TQT_SLOT( redeye() ) );
}
SQ_ImageFilter* SQ_ImageFilter::instance()
@@ -2,7 +2,7 @@
**
** If you wish to add, delete or rename functions or slots use
-** Qt Designer which will update this file, preserving your code. Create an
+** TQt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.